@@ -604,11 +604,8 @@ tracker_miner_manager_new_full (gboolean   auto_start,
 	                          &inner_error,
 	                          "auto-start", auto_start,
 	                          NULL);
-	if (!manager) {
-		g_critical ("Couldn't create new TrackerMinerManager: '%s'",
-		            inner_error ? inner_error->message : "unknown error");
-		g_clear_error (&inner_error);
-	}
+	if (inner_error)
+		g_propagate_error (error, inner_error);
 
 	return manager;
 }
@@ -620,9 +617,9 @@ tracker_miner_manager_new_full (gboolean   auto_start,
  * Returns a list of references for all active miners. Active miners
  * are miners which are running within a process.
  *
- * Returns: (transfer full): a #GSList which must be freed with g_slist_free() and all
- * contained data with g_free(). Otherwise %NULL is returned if there
- * are no miners.
+ * Returns: (transfer full) (element-type utf8): a #GSList which must
+ * be freed with g_slist_free() and all contained data with g_free().
+ * Otherwise %NULL is returned if there are no miners.
  *
  * Since: 0.8
  **/
@@ -798,9 +795,9 @@ initialize_miners_data (TrackerMinerManager *manager)
  * miners are miners which may or may not be running in a process at
  * the current time.
  *
- * Returns: (transfer full): a #GSList which must be freed with g_slist_free() and all
- * contained data with g_free(). Otherwise %NULL is returned if there
- * are no miners.
+ * Returns: (transfer full) (element-type utf8): a #GSList which must
+ * be freed with g_slist_free() and all contained data with g_free().
+ * Otherwise %NULL is returned if there are no miners.
  *
  * Since: 0.8
  **/
@@ -827,7 +824,7 @@ tracker_miner_manager_get_available (TrackerMinerManager *manager)
  * @manager: a #TrackerMinerManager.
  * @miner: miner reference
  * @reason: reason to pause
- * @cookie: return location for the pause cookie ID
+ * @cookie: (out) (allow-none): return location for the pause cookie ID
  *
  * Asks @miner to pause. a miner could be paused by
  * several reasons, and its activity won't be resumed
@@ -899,7 +896,7 @@ tracker_miner_manager_pause (TrackerMinerManager *manager,
  * @manager: a #TrackerMinerManager.
  * @miner: miner reference
  * @reason: reason to pause
- * @cookie: return location for the pause cookie ID
+ * @cookie: (out) (allow-none): return location for the pause cookie ID
  *
  * This function operates exactly the same way as
  * tracker_miner_manager_pause() with the exception that if the calling
@@ -1190,8 +1187,10 @@ tracker_miner_manager_get_status (TrackerMinerManager  *manager,
  * tracker_miner_manager_is_paused:
  * @manager: a #TrackerMinerManager
  * @miner: miner reference
- * @applications: (out callee-allocates) (allow-none) (transfer full): return location for application names.
- * @reasons: (out callee-allocates) (allow-none) (transfer full): return location for pause reasons.
+ * @applications: (out callee-allocates) (allow-none) (transfer full):
+ * return location for application names.
+ * @reasons: (out callee-allocates) (allow-none) (transfer full):
+ * return location for pause reasons.
  *
  * This function either returns %FALSE if the miner is not paused,
  * or returns %TRUE and fills in @applications and @reasons with
