@@ -25,15 +25,13 @@
 #include <gio/gunixoutputstream.h>
 
 #include <libtracker-common/tracker-file-utils.h>
-#include <libtracker-common/tracker-common.h>
 
 #include "tracker-writeback-file.h"
 
-static gboolean tracker_writeback_file_update_metadata (TrackerWriteback         *writeback,
-                                                        GPtrArray                *values,
-                                                        TrackerSparqlConnection  *connection,
-                                                        GCancellable             *cancellable,
-                                                        GError                  **error);
+static gboolean tracker_writeback_file_update_metadata (TrackerWriteback        *writeback,
+                                                        GPtrArray               *values,
+                                                        TrackerSparqlConnection *connection,
+                                                        GCancellable            *cancellable);
 
 G_DEFINE_ABSTRACT_TYPE (TrackerWritebackFile, tracker_writeback_file, TRACKER_TYPE_WRITEBACK)
 
@@ -51,9 +49,8 @@ tracker_writeback_file_init (TrackerWritebackFile *writeback_file)
 }
 
 static GFile *
-create_temporary_file (GFile      *file,
-                       GFileInfo  *file_info,
-                       GError    **in_error)
+create_temporary_file (GFile     *file,
+                       GFileInfo *file_info)
 {
 	GInputStream *input_stream;
 	GOutputStream *output_stream;
@@ -70,12 +67,6 @@ create_temporary_file (GFile      *file,
 		g_warning ("Could not create temporary file, file is not native: '%s'", uri);
 		g_free (uri);
 
-		g_set_error (in_error,
-		             G_IO_ERROR,
-		             G_IO_ERROR_FAILED,
-		             "Could not create temporary file, file is not native: '%s'",
-		             uri);
-
 		return NULL;
 	}
 
@@ -84,7 +75,7 @@ create_temporary_file (GFile      *file,
 
 	if (error) {
 		g_critical ("Could not create temporary file, %s", error->message);
-		g_propagate_error (in_error, error);
+		g_error_free (error);
 		return NULL;
 	}
 
@@ -120,7 +111,8 @@ create_temporary_file (GFile      *file,
 
 	if (error) {
 		g_critical ("Could not copy temporary file, %s", error->message);
-		g_propagate_error (in_error, error);
+		g_error_free (error);
+
 		g_file_delete (tmp_file, NULL, NULL);
 		g_object_unref (tmp_file);
 
@@ -131,11 +123,10 @@ create_temporary_file (GFile      *file,
 }
 
 static gboolean
-tracker_writeback_file_update_metadata (TrackerWriteback         *writeback,
-                                        GPtrArray                *values,
-                                        TrackerSparqlConnection  *connection,
-                                        GCancellable             *cancellable,
-                                        GError                  **error)
+tracker_writeback_file_update_metadata (TrackerWriteback        *writeback,
+                                        GPtrArray               *values,
+                                        TrackerSparqlConnection *connection,
+                                        GCancellable            *cancellable)
 {
 	TrackerWritebackFileClass *writeback_file_class;
 	gboolean retval;
@@ -145,33 +136,18 @@ tracker_writeback_file_update_metadata (TrackerWriteback         *writeback,
 	const gchar * const *content_types;
 	const gchar *mime_type;
 	guint n;
-	GError *n_error = NULL;
 
 	writeback_file_class = TRACKER_WRITEBACK_FILE_GET_CLASS (writeback);
 
 	if (!writeback_file_class->update_file_metadata) {
 		g_critical ("%s doesn't implement update_file_metadata()",
 		            G_OBJECT_TYPE_NAME (writeback));
-
-		g_set_error (error,
-		             G_IO_ERROR,
-		             G_IO_ERROR_FAILED,
-		             "%s doesn't implement update_file_metadata()",
-		             G_OBJECT_TYPE_NAME (writeback));
-
 		return FALSE;
 	}
 
 	if (!writeback_file_class->content_types) {
 		g_critical ("%s doesn't implement content_types()",
 		            G_OBJECT_TYPE_NAME (writeback));
-
-		g_set_error (error,
-		             G_IO_ERROR,
-		             G_IO_ERROR_FAILED,
-		             "%s doesn't implement content_types()",
-		             G_OBJECT_TYPE_NAME (writeback));
-
 		return FALSE;
 	}
 
@@ -187,13 +163,6 @@ tracker_writeback_file_update_metadata (TrackerWriteback         *writeback,
 
 	if (!file_info) {
 		g_object_unref (file);
-
-		g_set_error (error,
-		             G_IO_ERROR,
-		             G_IO_ERROR_FAILED,
-		             "%s doesn't exist",
-		             row[0]);
-
 		return FALSE;
 	}
 
@@ -211,25 +180,19 @@ tracker_writeback_file_update_metadata (TrackerWriteback         *writeback,
 
 	if (!retval) {
 		/* module does not support writeback for this file */
-		g_object_unref (file);
 		g_object_unref (file_info);
-
-		g_set_error_literal (error,
-		                     TRACKER_DBUS_ERROR,
-		                     TRACKER_DBUS_ERROR_UNSUPPORTED,
-		                     "Module does not support writeback for this file");
+		g_object_unref (file);
 
 		return FALSE;
 	}
 
 	/* Copy to a temporary file so we can perform an atomic write on move */
-	tmp_file = create_temporary_file (file, file_info, &n_error);
+	tmp_file = create_temporary_file (file, file_info);
+
+	g_object_unref (file_info);
 
 	if (!tmp_file) {
 		g_object_unref (file);
-		g_object_unref (file_info);
-
-		g_propagate_error (error, n_error);
 
 		return FALSE;
 	}
@@ -238,8 +201,7 @@ tracker_writeback_file_update_metadata (TrackerWriteback         *writeback,
 	                                                       tmp_file,
 	                                                       values,
 	                                                       connection,
-	                                                       cancellable,
-	                                                       &n_error);
+	                                                       cancellable);
 
 	if (!retval) {
 		/* Delete the temporary file and preserve original */
@@ -252,12 +214,7 @@ tracker_writeback_file_update_metadata (TrackerWriteback         *writeback,
 	}
 
 	g_object_unref (tmp_file);
-	g_object_unref (file_info);
 	g_object_unref (file);
 
-	if (n_error) {
-		g_propagate_error (error, n_error);
-	}
-
 	return retval;
 }
