@@ -393,7 +393,7 @@ class ExtractorHelper (Helper):
         """
         metadata = {}
         try:
-            preupdate, embedded, where = self.extractor.GetMetadata (filename, mime)
+            preupdate, embedded, where = self.extractor.GetMetadata (filename, mime, "")
             extras = self.__process_where_part (where)
             for attribute_value in self.__process_lines (embedded):
                 att, value = attribute_value.split (" ", 1)
